==> haskell-binary-parser-0.5.7.7-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-parser
version:              0.5.7.7
visibility:           public
id:                   binary-parser-0.5.7.7-HeJKbHxRiBJBxa636HLkY
key:                  binary-parser-0.5.7.7-HeJKbHxRiBJBxa636HLkY
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/binary-parser
synopsis:
    An efficient but limited parser API specialised to bytestrings

category:             Parser, Binary
abi:                  7ef2e217550e4638e9d1650f94b4bbac
exposed:              True
exposed-modules:      BinaryParser
hidden-modules:       BinaryParser.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-parser
hs-libraries:         HSbinary-parser-0.5.7.7-HeJKbHxRiBJBxa636HLkY
depends:
    base-4.17.2.1 bytestring-0.11.5.3 mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock

haddock-html:         /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-parser-0.5.7.7-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-parser
version:              0.5.7.7
visibility:           public
id:                   binary-parser-0.5.7.7-F4eMoAPxjTR1NWMZzRcdZE
key:                  binary-parser-0.5.7.7-F4eMoAPxjTR1NWMZzRcdZE
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/binary-parser
synopsis:
    An efficient but limited parser API specialised to bytestrings

category:             Parser, Binary
abi:                  9914a9022bac4d5d1efca91b43696bda
exposed:              True
exposed-modules:      BinaryParser
hidden-modules:       BinaryParser.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-parser
hs-libraries:         HSbinary-parser-0.5.7.7-F4eMoAPxjTR1NWMZzRcdZE
depends:
    base-4.17.2.1 bytestring-0.11.5.3 mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock

haddock-html:         /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
